@@ -26,6 +26,8 @@ setClass(Class = "gergm",
            observed_simulated_t_test = "data.frame",
            console_output = "character",
            print_output = "logical",
+           is_correlation_network = "logical",
+           beta_correlation_model = "logical",
            directed_network = "logical",
            simulation_only = "logical",
            thresholds = "numeric",
